@@ -47,11 +47,11 @@ struct lxc_arguments {
 	const char *statefile;
 
 	/* for lxc-checkpoint */
-	int kill;
-	int pause;
+	int flags;
 
 	/* for lxc-console */
 	int ttynum;
+	char escape;
 
 	/* for lxc-wait */
 	char *states;
