@@ -26,11 +26,14 @@
 #include <netinet/in.h>
 #include <sys/param.h>
 
+#include <lxc/list.h>
+
 enum {
 	EMPTY,
 	VETH,
 	MACVLAN,
 	PHYS,
+	VLAN,
 	MAXCONFTYPE,
 };
 
@@ -67,35 +70,47 @@ struct lxc_inet6dev {
 struct lxc_route6 {
 	struct in6_addr addr;
 };
+
+struct ifla_veth {
+	char *pair; /* pair name */
+};
+
+struct ifla_vlan {
+	uint   flags;
+	uint   fmask;
+	ushort   vid;
+	ushort   pad;
+};
+
+struct ifla_macvlan {
+	int mode; /* private, vepa, bridge */
+};
+
+union netdev_p {
+	struct ifla_veth veth_attr;
+	struct ifla_vlan vlan_attr;
+	struct ifla_macvlan macvlan_attr;
+};
+
 /*
  * Defines a structure to configure a network device
- * @ifname : network device name
+ * @link   : lxc.network.link, name of bridge or host iface to attach if any
+ * @name   : lxc.network.name, name of iface on the container side
  * @flags  : flag of the network device (IFF_UP, ... )
  * @ipv4   : a list of ipv4 addresses to be set on the network device
  * @ipv6   : a list of ipv6 addresses to be set on the network device
  */
 struct lxc_netdev {
+	int type;
 	int flags;
-	char *ifname;
-	char *newname;
+	int ifindex;
+	char *link;
+	char *name;
 	char *hwaddr;
 	char *mtu;
+	union netdev_p priv;
 	struct lxc_list ipv4;
 	struct lxc_list ipv6;
-	struct lxc_list route4;
-	struct lxc_list route6;
-};
-
-/*
- * Defines the kind of the network to use
- * @type : the type of the network virtualization
- * @phys : phys configuration type
- * @veth : veth configuration type
- * @macvlan : macvlan configuration type
- */
-struct lxc_network {
-	int type;
-	struct lxc_list netdev;
 };
 
 /*
@@ -109,23 +124,6 @@ struct lxc_cgroup {
 	char *value;
 };
 
-/*
- * Defines the global container configuration
- * @rootfs  : the root directory to run the container
- * @mount   : the list of mount points
- * @network : the network configuration
- * @utsname : the container utsname
- */
-struct lxc_conf {
-	char *rootfs;
-	char *fstab;
-	int tty;
-	int pts;
-	struct utsname *utsname;
-	struct lxc_list cgroup;
-	struct lxc_list networks;
-};
-
 /*
  * Defines a structure containing a pty information for
  * virtualizing a tty
@@ -150,42 +148,45 @@ struct lxc_tty_info {
 	struct lxc_pty_info *pty_info;
 };
 
+/*
+ * Defines the global container configuration
+ * @rootfs  : the root directory to run the container
+ * @mount   : the list of mount points
+ * @network : the network configuration
+ * @utsname : the container utsname
+ */
+struct lxc_conf {
+	char *rootfs;
+	char *pivotdir;
+	char *fstab;
+	int tty;
+	int pts;
+	struct utsname *utsname;
+	struct lxc_list cgroup;
+	struct lxc_list network;
+	struct lxc_list mount_list;
+	struct lxc_list caps;
+	struct lxc_tty_info tty_info;
+	char console[MAXPATHLEN];
+};
+
 /*
  * Initialize the lxc configuration structure
  */
-extern int lxc_conf_init(struct lxc_conf *conf);
+extern struct lxc_conf *lxc_conf_init(void);
 
-/*
- * Configure the external resources for the container
- */
-extern int lxc_configure(const char *name, struct lxc_conf *conf);
+extern int lxc_create_network(struct lxc_list *networks);
+extern int lxc_assign_network(struct lxc_list *networks, pid_t pid);
 
-/*
- * Remove the resources created by the configuration
- */
-extern int lxc_unconfigure(const char *name);
-
-extern int conf_create_network(const char *name, pid_t pid);
-
-extern int conf_destroy_network(const char *name);
-
-extern int lxc_create_tty(const char *name, struct lxc_tty_info *tty_info);
+extern int lxc_create_tty(const char *name, struct lxc_conf *conf);
 extern void lxc_delete_tty(struct lxc_tty_info *tty_info);
 
 /*
  * Configure the container from inside
  */
-extern int lxc_setup(const char *name, const char *tty,
-		     const struct lxc_tty_info *tty_info);
 
-extern int conf_has(const char *name, const char *info);
+struct lxc_handler;
+
+extern int lxc_setup(const char *name, struct lxc_conf *lxc_conf);
 
-#define conf_has_fstab(__name)   conf_has(__name, "fstab")
-#define conf_has_rootfs(__name)  conf_has(__name, "rootfs")
-#define conf_has_utsname(__name) conf_has(__name, "utsname")
-#define conf_has_network(__name) conf_has(__name, "network")
-#define conf_has_console(__name) conf_has(__name, "console")
-#define conf_has_cgroup(__name)  conf_has(__name, "cgroup")
-#define conf_has_tty(__name)     conf_has(__name, "tty")
-#define conf_has_pts(__name)     conf_has(__name, "pts")
 #endif
