@@ -20,8 +20,11 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
+#define _GNU_SOURCE
 #include <stdio.h>
+#undef _GNU_SOURCE
 #include <libgen.h>
+#include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
 #include <termios.h>
@@ -37,22 +40,32 @@
 #include <netinet/in.h>
 #include <net/if.h>
 
-#include <lxc/lxc.h>
-#include <lxc/log.h>
+#include "log.h"
+#include "lxc.h"
+#include "conf.h"
+#include "utils.h"
+#include "config.h"
+#include "confile.h"
 #include "arguments.h"
 
-lxc_log_define(lxc_start, lxc);
+lxc_log_define(lxc_start_ui, lxc_start);
+
+static struct lxc_list defines;
 
 static int my_parser(struct lxc_arguments* args, int c, char* arg)
 {
 	switch (c) {
 	case 'd': args->daemonize = 1; break;
+	case 'f': args->rcfile = arg; break;
+	case 's': return lxc_config_define_add(&defines, arg);
 	}
 	return 0;
 }
 
 static const struct option my_longopts[] = {
 	{"daemon", no_argument, 0, 'd'},
+	{"rcfile", required_argument, 0, 'f'},
+	{"define", required_argument, 0, 's'},
 	LXC_COMMON_OPTIONS
 };
 
@@ -65,7 +78,9 @@ lxc-start start COMMAND in specified container NAME\n\
 \n\
 Options :\n\
   -n, --name=NAME      NAME for name of the container\n\
-  -d, --daemon         daemonize the container",
+  -d, --daemon         daemonize the container\n\
+  -f, --rcfile=FILE    Load configuration file FILE\n\
+  -s, --define KEY=VAL Assign VAL to configuration variable KEY\n",
 	.options   = my_longopts,
 	.parser    = my_parser,
 	.checker   = NULL,
@@ -102,7 +117,6 @@ static int restore_tty(struct termios *tios)
 	if (!memcmp(tios, &current_tios, sizeof(*tios)))
 		return 0;
 
-
 	oldhandler = signal(SIGTTOU, SIG_IGN);
 	ret = tcsetattr(0, TCSADRAIN, tios);
 	if (ret)
@@ -123,6 +137,11 @@ int main(int argc, char *argv[])
 		'\0',
 	};
 
+	char *rcfile = NULL;
+	struct lxc_conf *conf;
+
+	lxc_list_init(&defines);
+
 	if (lxc_arguments_parse(&my_args, argc, argv))
 		return err;
 
@@ -135,6 +154,41 @@ int main(int argc, char *argv[])
 			 my_args.progname, my_args.quiet))
 		return err;
 
+	/* rcfile is specified in the cli option */
+	if (my_args.rcfile)
+		rcfile = (char *)my_args.rcfile;
+	else {
+		if (!asprintf(&rcfile, LXCPATH "/%s/config", my_args.name)) {
+			SYSERROR("failed to allocate memory");
+			return err;
+		}
+
+		/* container configuration does not exist */
+		if (access(rcfile, F_OK)) {
+			free(rcfile);
+			rcfile = NULL;
+		}
+	}
+
+	conf = lxc_conf_init();
+	if (!conf) {
+		ERROR("failed to initialize configuration");
+		return err;
+	}
+
+	if (rcfile && lxc_config_read(rcfile, conf)) {
+		ERROR("failed to read configuration file");
+		return err;
+	}
+
+	if (lxc_config_define_load(&defines, conf))
+		return err;
+
+	if (!rcfile && !strcmp("/sbin/init", args[0])) {
+		ERROR("no configuration file for '/sbin/init' (may crash the host)");
+		return err;
+	}
+
 	if (my_args.daemonize) {
 
                 /* do not chdir as we want to open the log file,
@@ -157,13 +211,11 @@ int main(int argc, char *argv[])
 			open(my_args.log_file, O_RDONLY | O_CLOEXEC);
 			open(my_args.log_file, O_RDONLY | O_CLOEXEC);
 		}
-
-		chdir("/");
 	}
 
 	save_tty(&tios);
 
-	err = lxc_start(my_args.name, args);
+	err = lxc_start(my_args.name, args, conf);
 
 	restore_tty(&tios);
 
